json_error

Function json_error 

pub fn json_error(
    status: StatusCode,
    message: impl Into<String>,
) -> HttpResponse
Build bamboo’s canonical JSON error response for code paths that cannot return an AppError directly (most notably middleware and handlers that must preserve extra response headers).