Module runtime

Module runtime 

Structs

CompositeExternalChildRunner
Composite router that delegates to the first matching external child runner.

Functions

build_external_child_runner
Build an external child runner from the application config.