validate_project_path_candidate_with_resolver

Function validate_project_path_candidate_with_resolver 

pub fn validate_project_path_candidate_with_resolver(
    store: &ProjectStore,
    project_id: Option<&ProjectId>,
    project_path: &str,
    workspace_resolver: &WorkspaceResolver,
) -> Result<PathBuf, ProjectWorkspaceValidationError>
Validate a proposed authoritative Project path with the same canonicalization, confinement, and ownership rules used at session resolution time. project_id is None during create and the existing stable ID during a CAS update.