Module server

Module server 

Unified HTTP server entry points

Consolidates run(), run_with_bind(), WebService from web_service/server.rs Eliminates the proxy pattern by using unified AppState

Structs

WebService
Manageable web service with start/stop lifecycle

Functions

run
Run the unified server in desktop mode (localhost only, no rate limiting)
run_with_bind
Run the unified server with custom bind address (Docker/production mode)
run_with_bind_and_static
Run the unified server with custom bind address and static file serving