pub fn parse_goal_command(message: &str) -> Option<GoalCommand>Expand description
Attempt to parse a /goal command from the raw user message.
Returns None if the message is not a /goal command.
pub fn parse_goal_command(message: &str) -> Option<GoalCommand>Attempt to parse a /goal command from the raw user message.
Returns None if the message is not a /goal command.