Unified HTTP server entry points
Consolidates run(), run_with_bind(), WebService from web_service/server.rs Eliminates the proxy pattern by using unified AppState
Structs
- WebService
- Manageable web service with start/stop lifecycle
Functions
- run
- Run the unified server in desktop mode (localhost only, no rate limiting)
- run_
with_ bind - Run the unified server with custom bind address (Docker/production mode)
- run_
with_ bind_ and_ static - Run the unified server with custom bind address and static file serving
- run_
with_ bind_ and_ static_ tls - Like
run_with_bind_and_static, but terminates TLS itself whentlsisSome(#181). WhenNone, the plaintext.listen()path is unchanged. - run_
with_ bind_ tls - Like
run_with_bind, but terminates TLS itself whentlsisSome(#181). - run_
with_ tls - Like
run, but terminates TLS itself whentlsisSome(#181).