Module services

Module services 

Business services for the Bamboo server

This module provides service layer components that handle business logic for various server operations, including model mapping and skill management.

Modules

frontend_package
gemini_model_mapping_service
gold_auto_answer
Server-side regression tests for the engine Gold auto-answer service.
skill_service